"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnonCredsRsIssuerService = void 0;
const anoncreds_1 = require("@aries-framework/anoncreds");
const core_1 = require("@aries-framework/core");
const anoncreds_shared_1 = require("@hyperledger/anoncreds-shared");
const AnonCredsRsError_1 = require("../errors/AnonCredsRsError");
let AnonCredsRsIssuerService = class AnonCredsRsIssuerService {
    async createSchema(agentContext, options) {
        const { issuerId, name, version, attrNames: attributeNames } = options;
        try {
            const schema = anoncreds_shared_1.Schema.create({
                issuerId,
                name,
                version,
                attributeNames,
            });
            return JSON.parse(schema.toJson());
        }
        catch (error) {
            throw new AnonCredsRsError_1.AnonCredsRsError('Error creating schema', { cause: error });
        }
    }
    async createCredentialDefinition(agentContext, options) {
        const { tag, supportRevocation, schema, issuerId, schemaId } = options;
        try {
            const { credentialDefinition, credentialDefinitionPrivate, keyCorrectnessProof } = anoncreds_shared_1.CredentialDefinition.create({
                schema: anoncreds_shared_1.Schema.load(JSON.stringify(schema)),
                issuerId,
                schemaId,
                tag,
                supportRevocation,
                signatureType: 'CL',
            });
            return {
                credentialDefinition: JSON.parse(credentialDefinition.toJson()),
                credentialDefinitionPrivate: JSON.parse(credentialDefinitionPrivate.toJson()),
                keyCorrectnessProof: JSON.parse(keyCorrectnessProof.toJson()),
            };
        }
        catch (error) {
            throw new AnonCredsRsError_1.AnonCredsRsError('Error creating credential definition', { cause: error });
        }
    }
    async createCredentialOffer(agentContext, options) {
        const { credentialDefinitionId } = options;
        try {
            const credentialDefinitionRecord = await agentContext.dependencyManager
                .resolve(anoncreds_1.AnonCredsCredentialDefinitionRepository)
                .getByCredentialDefinitionId(agentContext, options.credentialDefinitionId);
            const keyCorrectnessProofRecord = await agentContext.dependencyManager
                .resolve(anoncreds_1.AnonCredsKeyCorrectnessProofRepository)
                .getByCredentialDefinitionId(agentContext, options.credentialDefinitionId);
            if (!credentialDefinitionRecord) {
                throw new AnonCredsRsError_1.AnonCredsRsError(`Credential Definition ${credentialDefinitionId} not found`);
            }
            const credentialOffer = anoncreds_shared_1.CredentialOffer.create({
                credentialDefinitionId,
                keyCorrectnessProof: anoncreds_shared_1.KeyCorrectnessProof.load(JSON.stringify(keyCorrectnessProofRecord === null || keyCorrectnessProofRecord === void 0 ? void 0 : keyCorrectnessProofRecord.value)),
                schemaId: credentialDefinitionRecord.credentialDefinition.schemaId,
            });
            return JSON.parse(credentialOffer.toJson());
        }
        catch (error) {
            throw new AnonCredsRsError_1.AnonCredsRsError(`Error creating credential offer: ${error}`, { cause: error });
        }
    }
    async createCredential(agentContext, options) {
        var _a;
        const { tailsFilePath, credentialOffer, credentialRequest, credentialValues, revocationRegistryId } = options;
        try {
            if (revocationRegistryId || tailsFilePath) {
                throw new core_1.AriesFrameworkError('Revocation not supported yet');
            }
            const attributeRawValues = {};
            const attributeEncodedValues = {};
            Object.keys(credentialValues).forEach((key) => {
                attributeRawValues[key] = credentialValues[key].raw;
                attributeEncodedValues[key] = credentialValues[key].encoded;
            });
            const credentialDefinitionRecord = await agentContext.dependencyManager
                .resolve(anoncreds_1.AnonCredsCredentialDefinitionRepository)
                .getByCredentialDefinitionId(agentContext, options.credentialRequest.cred_def_id);
            const credentialDefinitionPrivateRecord = await agentContext.dependencyManager
                .resolve(anoncreds_1.AnonCredsCredentialDefinitionPrivateRepository)
                .getByCredentialDefinitionId(agentContext, options.credentialRequest.cred_def_id);
            const credential = anoncreds_shared_1.Credential.create({
                credentialDefinition: anoncreds_shared_1.CredentialDefinition.load(JSON.stringify(credentialDefinitionRecord.credentialDefinition)),
                credentialOffer: anoncreds_shared_1.CredentialOffer.load(JSON.stringify(credentialOffer)),
                credentialRequest: anoncreds_shared_1.CredentialRequest.load(JSON.stringify(credentialRequest)),
                revocationRegistryId,
                attributeEncodedValues,
                attributeRawValues,
                credentialDefinitionPrivate: anoncreds_shared_1.CredentialDefinitionPrivate.load(JSON.stringify(credentialDefinitionPrivateRecord.value)),
            });
            return {
                credential: JSON.parse(credential.toJson()),
                credentialRevocationId: (_a = credential.revocationRegistryIndex) === null || _a === void 0 ? void 0 : _a.toString(),
            };
        }
        catch (error) {
            throw new AnonCredsRsError_1.AnonCredsRsError(`Error creating credential: ${error}`, { cause: error });
        }
    }
};
AnonCredsRsIssuerService = __decorate([
    (0, core_1.injectable)()
], AnonCredsRsIssuerService);
exports.AnonCredsRsIssuerService = AnonCredsRsIssuerService;
//# sourceMappingURL=AnonCredsRsIssuerService.js.map